<?php
function tf_googleMaps( $venue ) {
	$lat_long_safe  = esc_html( $venue->lat . ',' . $venue->lng );
	$venueName_safe = esc_html( $venue->name );
	$venue_id_safe  = esc_html( $venue->id );
	$venueMapJS     = '
//                  var map' . $venue_id_safe . ';
                  function initialize' . $venue_id_safe . '() {
                    var myLatlng = new google.maps.LatLng(' . $lat_long_safe . ');
                    var myOptions = {
                      zoom: 15,
                      center: myLatlng,
                      mapTypeId: google.maps.MapTypeId.ROADMAP
                    };
                    map' . $venue_id_safe . ' = new google.maps.Map(document.getElementById("googlemap-' . $venue_id_safe . '"),
                        myOptions);

                    var marker = new google.maps.Marker({
                          position: myLatlng,
                          title: "' . $venueName_safe . '"
                      });

                      // To add the marker to the map, call setMap();
                      marker.setMap(map' . $venue_id_safe . ');
                  }

                  google.maps.event.addDomListener(window, "load", initialize' . $venue_id_safe . ');
';

	return $venueMapJS;
}


function print_venueInfo( $venueInfo, $atts ) {
	global $post;

	$atts = wp_parse_args( $atts, [
		'title'    => 'Venue Information',
		'exclude'  => 'ical,gcal',
		'calshare' => 'true',
		'style'    => 'map',
	] );

	$exclude = explode( ",", $atts[ 'exclude' ] );

	if ( isset( $post->eb_id ) && ( $post->eb_events_page_role === 'venue_details' ) ) { ?>

		<div id="tfly-venue-information">
			<?php if ( ! in_array( "title", $exclude, true ) ) { ?>
				<h2><?php echo esc_html( $atts[ 'title' ] ); ?></h2>
			<?php } ?>
			<div class="tfly-venuedetails-metadata">
				<?php if ( eb_is_valid_field( $venueInfo->name ) && ! in_array( "venuename", $exclude, true ) ) { ?>
					<div class="tfly-venuedetails-venuename"><?php echo esc_html( $venueInfo->name ); ?></div>
				<?php }
				if ( eb_is_valid_field( $venueInfo->address1 ) && ! in_array( "address1", $exclude, true ) ) { ?>
					<div class="tfly-venuedetails-address1"><?php echo esc_html( $venueInfo->address1 ); ?></div>
				<?php }
				if ( eb_is_valid_field( $venueInfo->address2 ) && ! in_array( "address2", $exclude, true ) ) { ?>
					<div class="tfly-venuedetails-address2"><?php echo esc_html( $venueInfo->address2 ); ?></div>
				<?php }
				if ( eb_is_valid_field( $venueInfo->city ) && ! in_array( "city", $exclude, true ) ) { ?>
					<div class="tfly-venuedetails-city"><?php echo esc_html( $venueInfo->city . ', ' . esc_html( $venueInfo->stateProvince ) . ' ' . $venueInfo->postalCode ); ?></div>
				<?php }
				if ( ! in_array(
					"googlemaps",
					$exclude,
					true 
				) && ( isset( $venueInfo->address1 ) || isset( $venueInfo->city ) ) ) {
					if ( 'map' === $atts[ 'style' ] ) {
						$driving_directions_url = 'https://maps.google.com/maps?daddr=' . url_encode( $venueInfo->address1 . ', ' . $venueInfo->city . ', ' . $venueInfo->stateProvince . ' ' . $venueInfo->postalCode ); ?>
						<div class="eb-venuedetails-map" id="googlemap-<?php echo esc_attr( $venueInfo->id ); ?>"></div>
						<div class="tfly-venuedetails-directions"><a
									href="<?php echo esc_url( $driving_directions_url ); ?>" target="_blank"
									rel="noopener">Driving Directions</a></div>
						<?php global $venueInits;
						$venueInits = '<script type="text/javascript">' . tf_googleMaps( $venueInfo ) . '</script>';
						add_action( 'wp_footer', 'tfly_injectGMapsJS' );
					} else {
						$googleMapsAddress = $venueInfo->address1 . ", " . $venueInfo->city . ", " . $venueInfo->stateProvince . " " . $venueInfo->postalCode; ?>
						<div class="tfly-venuedetails-googlemap"><a
									href="<?php echo esc_url( 'https://maps.google.com/?q=' . $googleMapsAddress ); ?>">Google
								Map</a></div>
					<?php }
				}
				if ( eb_is_valid_field( $venueInfo->url ) && ! in_array( "url", $exclude, true ) ) { ?>
					<div class="tfly-venuedetails-url"><a href="<?php echo esc_url( $venueInfo->url ); ?>">Venue
							Website</a></div>
				<?php }
				$calLink = trailingslashit( get_bloginfo( 'home' ) ) . eb_URL(
					'ical',
					$post->eb_id,
					$post->eb_events_page_role 
				);
		if ( false && ! in_array( "ical", $exclude, true ) ) {
			?>
					<a class="tfly-ical" href="<?php echo esc_url( $calLink ); ?>">iCal</a>
		<?php }
		if ( false && ! in_array( "gcal", $exclude, true ) ) {
			$calLink = str_replace( 'https', 'http', $calLink );
			?>
					<a class="tfly-gcal"
					   href="<?php esc_url( 'https://www.google.com/calendar/render?cid=' . rawurlencode( $calLink ) ); ?>"
					   target="_blank" rel="noopener">Google Calendar</a>
		<?php }
		?>
			</div>
		</div>
		<?php
	}
}
