<?php

global $post;

extract( wp_parse_args( $atts, [
	'timezone'          => '',
	'dateformat'        => 'M j, Y',
	'timeformat'        => '',
	'exclude'           => '',
	'include'           => '',
	'fbcommentspos'     => 'above',
	'share'             => 'default',
	'calsync'           => 'off',
	'linktarget'        => true,
	'eventid'           => '',
	'imagesize'         => 'large1',
	'eventinfosettimes' => 'false',

] ) );

add_action( 'wp_footer', 'eb_addArtistMoreToggle' );

$exclude = explode( ",", $exclude );
$include = explode( ",", $include );
$BIO_LEN = 500;

$attraction           = $post->api_data->attractionInfo;
$attractionLowercase  = strtolower( $attraction->name );
$attractionIds        = str_replace( ' ', '-', $attractionLowercase );
$attractionImage      = eb_imageTag(
	$attraction->image->$imagesize->path,
	$attraction->image->$imagesize->width,
	$attraction->image->$imagesize->height,
	$attraction->name,
	"",
	$imagesize
);
$attractionDateMarkup = tf_getAttractionDateMarkup( $attraction->startDate, $attraction->endDate, 'F j, Y', $exclude );
$has_more             = tfly_should_show_headliner( $attraction );

?>
<section class="attraction-detail <?php echo esc_attr( $attractionIds ); ?>">
	<section class="attraction-header">
		<?php
		// Image is properly escaped in eb_imageTag() function.
		echo $attractionImage; //phpcs:ignore
		if ( isset( $events->events[ 0 ] ) ) {
			echo '<h1 class="headliners summary">' . esc_html( $attraction->name ) . '</h1>';
			if ( ! in_array( "daterange", $exclude, true ) ) {
				echo '<h2 class="dates">' . esc_html( $attractionDateMarkup ) . '</h2>';
			}
		} else {
			echo '<h2 class="dates no-events">No upcoming events</h2>';
		}

		if ( ! in_array( "share-events", $exclude, true ) ) { ?>
			<div id="toolbox" class="share-events share-plus">
				<?php if ( ! in_array( "share-facebook", $exclude, true ) ) { ?>
					<div class="share-facebook">
						<a href="https://www.facebook.com/share.php?u=<?php echo esc_url( $tinyurlFB ); ?>"
						   onclick="return tfly_fbs_click('<?php echo esc_js( $tinyurlFB ); ?>');"
						   target="_blank"
						   class="facebook">Facebook</a>
					</div>
				<?php }
				if ( ! in_array( "share-twitter", $exclude, true ) ) { ?>
					<div class="share-twitter">
						<a href="<?php echo esc_url( $tweet_desc ); ?>" class="twitter"
						   target="_blank"<?php if ( ! in_array(
							   "share-twitter-js",
							   $exclude,
							   true 
						   ) ) {
										?> onClick="window.open('<?php echo esc_js( $tweet_desc ); ?>','new','width=550,height=330'); return false;"<?php 
										  } ?>>Twitter</a>
					</div>
				<?php } ?>
			</div><!-- #toolbox -->
		<?php } ?>
	</section> <!-- .attraction-header -->

	<div class="list-view">
		<?php
		if ( isset( $events->events[ 0 ] ) ) {
			foreach ( $events->events as $event ) {
				$urlVars   = eb_getInitialUrlVars( $event );
				$templPath = eb_locate_template( 'list-view-item-adp' );
				include( dirname( __FILE__ ) . '/../inc/listView-values.php' );
				if ( ! empty( $templPath ) ) {
					require $templPath;
				}
				$urlVars = null;
			}
		} else {
			$attractionValue = ( isset( $attraction->name ) ) ? ' for ' . $attraction->name : '';
			echo '<p>' . sprintf(
				"We're sorry, but we couldn't find any events %s.",
				esc_html( $attractionValue ) 
			) . '</p>';
		}
		?>
	</div>

	<?php
	// test if we want to display the artist boxes at all and/or either one
	if ( $has_more && ! in_array( "details", $exclude, true ) && $has_more ) { ?>
		<div class="artist-boxes">
			<div class="artist-box-headliner card">

				<div class="artist-headline secondary-text">
					<span class="artist-name"><?php echo esc_html( $attraction->name ); ?></span>
				</div>

				<div id="tfly-more">
					<ul class="tfly-more">

						<?php if ( isset( $attraction->urlOfficialWebsite ) && strlen( (string) $attraction->urlOfficialWebsite ) ) { ?>
							<li class="web">
								<a href="<?php echo esc_url( $attraction->urlOfficialWebsite ); ?>"
								   rel="nofollow"
								   target="_blank">Website</a>
							</li>
						<?php }

						if ( isset( $attraction->urlFacebook ) && strlen( (string) $attraction->urlFacebook ) ) { ?>
							<li class="facebook">
								<a href="<?php echo esc_url( $attraction->urlFacebook ); ?>"
								   rel="nofollow"
								   target="_blank">Facebook</a>
							</li>
						<?php }

						if ( isset( $attraction->twitterScreenName ) && strlen( (string) $attraction->twitterScreenName ) ) { ?>
							<li class="twitter">
								<a href="https://www.twitter.com/<?php echo esc_url( $attraction->twitterScreenName ); ?>"
								   rel="nofollow"
								   target="_blank">Twitter</a>
							</li>
						<?php }

						if ( isset( $attraction->urlInstagram ) && strlen( (string) $attraction->urlInstagram ) ) { ?>
							<li class="instagram">
								<a href="<?php echo esc_url( $attraction->urlInstagram ); ?>" rel="nofollow"
								   target="_blank">Instagram</a>
							</li>
						<?php }

						if ( isset( $attraction->urlBandcamp ) && strlen( (string) $attraction->urlBandcamp ) ) { ?>
							<li class="bandcamp">
								<a href="<?php echo esc_url( $attraction->urlBandcamp ); ?>" rel="nofollow"
								   target="_blank">Bandcamp</a>
							</li>
						<?php }

						if ( isset( $attraction->urlSoundcloud ) && strlen( (string) $attraction->urlSoundcloud ) ) { ?>
							<li class="soundcloud">
								<a href="<?php echo esc_url( $attraction->urlSoundcloud ); ?>" rel="nofollow"
								   target="_blank">Soundcloud</a>
							</li>
						<?php }

						if ( isset( $attraction->urlPurchaseMusic ) && strlen( (string) $attraction->urlPurchaseMusic ) ) { ?>
							<li class="buy-music">
								<a href="<?php echo esc_url( $attraction->urlPurchaseMusic ); ?>" rel="nofollow"
								   target="_blank">Buy Music</a>
							</li>
						<?php } ?>

					</ul>
				</div><!-- .tfly-more -->

				<?php
				if ( isset( $attraction->bio ) && strlen( (string) $attraction->bio ) ) {
					echo '<div class="more-less tertiary-text"><div class="bio more-block">' . wp_kses_post(nl2br( $attraction->bio ) ) . '</div></div>';
				}
				?>
			</div><!-- .artist-box-headliner -->
		</div><!-- .artist-boxes -->
		<?php
	}
	?>
</section> <!-- ./attraction-detail -->
