<?php
global $post, $eventbrite_music;
require_once( WP_PLUGIN_DIR . '/eventbrite-events-public/includes/performers/Performers_View_Model.php' );
require_once( WP_PLUGIN_DIR . '/eventbrite-events-public/includes/performers/Performer_Options.php' );
$settings = $eventbrite_music->get_options();

$event         = ( $post->eb_event ) ? $post->eb_event : [];
$templateClass = 'eventdetail';
$eventdesc     = ( $post->description ) ? $post->description : [];
$performances  = ( $post->performances ) ? $post->performances : [];
if ( ! isset( $exclude ) ) {
	$exclude = [];
}

$edpUrl           = eb_URL( 'eb_event_details', $event->id);
$headlinersMarkup = ( ! in_array(
	"headliners",
	$exclude,
	true
) ) ? eb_getHeadlinersMarkup(
	eb_getPerformanceRoles( $performances, 'headliner' ),
	$templateClass,
	$edpUrl
) : '';
$supportsMarkup   = ( ! in_array(
	"supports",
	$exclude,
	true
) ) ? eb_getSupportsMarkup(
	eb_getPerformanceRoles( $performances, 'supporter' ),
	$templateClass,
	$edpUrl
) : '';

extract( wp_parse_args( $atts, [
	'timezone'        => '',
	'dateformat'      => 'D, F j, Y',
	'exclude'         => '',
	'include'         => '',
	'share'           => 'default',
	'calsync'         => 'off',
	'linktarget'      => true,
	'eventid'         => '',
	'imagesize'       => 'large',
	'performerslabel' => 'Performers: ',
] ) );

$exclude = explode( ",", $exclude );
$include = explode( ",", $include );
$BIO_LEN = 500;

function getArtistImages( $event = false, $imagesize = 'large1' ) {
	$performer = new Performers_View_Model( $event, new Performer_Options( [] ) );
	if ( ! isset( $event->id ) ) {
		return '';
	}
	$count = count( $performer->get_performer_images() );
	if ( $count === 0 ) {
		return '';
	}
	add_action( 'wp_footer', 'eb_edp_slider_js_init' );
	ob_start();

	date_default_timezone_set( $event->start->timezone ); ?>
	<div id="slider" class="swipe">
		<div class="swipe-wrap">

			<?php foreach ( $performer->get_performer_images() as $image ) {
				$image_path = eb_imageUrlBuild( $image[ 'url' ] );
				$image_tag  = eb_imageTag( $image_path, '', '', $image[ 'title' ], '', $imagesize, '' ); ?>
				<div class="slide">
					<?php echo $image_tag; //$image_tag is escaped in eb_imageTag ?>
					<div class="slider-overlay">
						<div class="event-name-venue">
							<?php echo esc_html( $image[ 'title' ] ); ?>
						</div>
					</div>
				</div>
				<?php
			} ?>
		</div>
	</div>
	<?php
	return ob_get_clean();
}

function eb_edp_slider_js_init() {
	?>
	<script type="text/javascript">

        jQuery(document).ready(function ($) {
            slider = new Swipe(document.getElementById('slider'), {
                speed: 600,
                auto: 5000,
                continuous: true,
                disableScroll: false
                //stopPropagation: false
            });
        });
	</script>
	<script>
        jQuery(function ($) {
            $('div.related-events').on('swiperight', swipeHandler);
            $('div.related-events').on('swipeleft', swipeHandler);

            function swipeHandler(event) {
                console.log(event);
                console.log($.event.originalEvent.touches);
                $(event.target).addClass('swipe');
            }
        });
	</script>
	<?php
}

function eb_artistDetailsMarkup( $event, $desc ) {
	$performers = new Performers_View_Model( $event, new Performer_Options( [] ) );
	ob_start();
	?>
	<section class="artist-boxes">
		<div class="artist-box-headliner card">
			<div class="artist-headline secondary-text">
			<span class="artist-name">
				<?php echo esc_html( $event->name->text ); ?>
			</span>
			</div>
			<div class="more-less tertiary-text">
				<div class="bio more-block">
					<?php add_filter( 'wp_kses_allowed_html', 'event_detail_kses_allowed_html', 10, 2 );
					echo wp_kses_post( $desc->description );
					remove_filter( 'wp_kses_allowed_html', 'event_detail_kses_allowed_html' ); ?>
				</div>
			</div>
	</section> <?php
	include( trailingslashit( __DIR__ ) . 'artist_template.php' );

	return ob_get_clean();
}

if ( ! isset( $event->id ) ) {
	$markup = '<section class"error-message">Sorry, something went wrong. We could not find the event.</section>';
} else {

	$sliderMarkup = ( ! in_array( "master-image", $exclude, true ) && ! in_array(
			"headliner-image",
			$exclude,
			true
		) ) ? getArtistImages( $event ) : '';

	// these are from the main template
	$templateClass      = 'eventdetail';
	$performers         = new Performers();
	$performancesMarkup = '<section class="performers">' . $performers->build_EDP_Performers(
			$event,
			$performances,
			$exclude
		) . '</section>';

	$artistDetailsMarkup = ! in_array( "description", $exclude, true ) ? eb_artistDetailsMarkup(
		$event,
		$eventdesc
	) : '';
	$shareEventsMarkup   = ! in_array( "share", $exclude, true ) ? '<button type="button" 
                            class="share-social-button share-button tertiary-text" data-target="share-modal">
                            <i class="ico-share"></i><span class="button-text">Share</span></button>'
	                                                               . eb_shareEventMarkup( $event, $exclude ) : '';
	$calSyncMarkup       = ( ( 'on' === $calsync ) || ( 'yes' === $calsync ) ) ? '<button aria-label="Add this event to your Calendar" type="button" class="share-cal-button share-button tertiary-text" data-target="calendar-modal"><i class="ico-calendar"></i><span class="button-text">Add To Calendar</span></button>' . eb_calSyncMarkup(
			'event',
			$event
		) : '';
	// end

	$classIds              = ( isset( $event->id ) ) ? ' ' . eb_addClassIds( $event ) : '';
	$venue_name_markup     = ( ( $event->venue->name ) && ! in_array( "venue", $exclude, true ) )
		? '<span class="venue location tertiary-text">' . $event->venue->name . '</span>'
		: '';
	$venueCityState_markup = ( ! in_array( "city-state", $exclude, true ) ) ?
		'<span class="city-state tertiary-text"><span class="city">' . $event->venue->address->city . '</span><span class="divider">,&nbsp;</span><span class="region">' . $event->venue->address->region . '</span></span>' : '';
	$startDate_markup      = eb_get_eventDates( $event, $exclude, $dateformat, 'dates' );
	$eventTime             = eb_get_eventTimes( $event, $include, $exclude );
	if ( $event->hide_start_date ) {
		$eventTime_markup = '<span class="times no-times"> </span>';
	} else {
		$eventTime_markup = ( ! in_array( "times", $exclude, true ) && $eventTime )
			? '<span class="times">' . $eventTime . '</span>'
			: $eventTime;
	}
	$moreInfo_markup         = '<span class="more-info"><a href="' . $edpUrl . '">More Info</a></span>';
	$location_markup         = ( ( $settings[ 'enable_venue_name' ] ) && ( $venue_name_markup || $venueCityState_markup ) ) ? '<address class="location">' . $venue_name_markup . $venueCityState_markup . '</address>' : '';
	$maxPrice                = $event->ticket_availability->maximum_ticket_price ? $event->ticket_availability->maximum_ticket_price->major_value : '';
	$minPrice                = $event->ticket_availability->minimum_ticket_price ? $event->ticket_availability->minimum_ticket_price->major_value : '';
	$currencySymbol          = $event->ticket_availability->maximum_ticket_price ? $event->ticket_availability->maximum_ticket_price->currency : '';
	$extLinkClass            = $event->is_externally_ticketed ? ' external-ticket' : '';
	$price                   = eb_get_cleanTicketPrice(
		$maxPrice,
		$minPrice,
		$currencySymbol,
		$event->is_free
	);
	$ticketPrice_markup      = ( ! in_array( "ticket-price", $exclude, true ) &&
	                             $price &&
	                             ! in_array( "price-range", $exclude, true ) &&
	                             ( $event->is_free === false ) )
		? '<section class="price-range">' . $price .'</section>'
		: '';
	$ageLimit_markup         = ( ! in_array(
			"age-restriction",
			$exclude,
			true
		) && $event->music_properties->age_restriction !== null && $event->music_properties->age_restriction )
		? '<section class="age-restriction' . '">' . eb_ageRestriction( $event->music_properties->age_restriction ) . '</section>'
		: '';
	$presentedBy             = ( $event->music_properties->presented_by !== null ) ? $event->music_properties->presented_by : '';
	$presentedBy_markup      = ( ! in_array( "topline-info", $exclude, true ) &&
	                             ! in_array( "presented-by", $exclude, true ) &&
	                             $presentedBy ) ?
		'<span class="topline-info presented-by">' . $presentedBy . '</span>'
		: '';
	$presentedByGroup_markup = ( $presentedBy_markup ) ? '<section class="topline-info secondary-text">' . $presentedBy_markup . '</section>' : '';
	$buyLink                 = ( ! in_array( "ticket-link-status", $exclude, true ) ) ? eb_buyTicketLink(
		$settings,
		$event,
		$dateformat
	) : '';
	$noLinkClass             = ( false !== strpos( $buyLink, 'href="' ) ) ? '' : ' no-link';

	add_action( 'wp_footer', 'eb_addArtistMoreToggle' );

	$markup = <<<MARKUP
    <section class="event-detail$classIds">
    	$sliderMarkup
        <section class="event-detail-wrapper">
			<section class="event-info card">
				<section class="event-headliners-supports">
                    $presentedByGroup_markup
                    $performancesMarkup
				</section>
				<section class="event-date-location-price">
					$startDate_markup
					$eventTime_markup
					$location_markup
					$ticketPrice_markup
					$ageLimit_markup
				</section> <!-- ./event-date-location-price -->
				<section class="event-calendar-share">
					$calSyncMarkup
					$shareEventsMarkup
				</section> <!-- ./event-date-location-price -->
			</section> <!-- ./event-info -->
			$artistDetailsMarkup
            <section class="ticket-links$noLinkClass">
                $buyLink
            </section>
		</section> <!-- ./event-details-wrapper -->
	</section> <!-- ./event-details -->

MARKUP;
}
add_filter( 'wp_kses_allowed_html', 'event_detail_kses_allowed_html', 10, 2 );
echo wp_kses_post( $markup );
remove_filter( 'wp_kses_allowed_html', 'event_detail_kses_allowed_html' );